@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.32 2006/09/04 10:21:29 khlut Exp $
+# $Id: mplayer.pl,v 1.33 2006/09/04 15:41:31 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -29,25 +29,22 @@ use Gtk2 -init;
 
 ## Parameters from the config file ##
 $conffile="$ENV{HOME}/.mozilla/genres/mplayer.conf";
+$filehelp=
+     "%@  in the filename will be replaced to source URL\n"
+    ."%Y - year \t%m - month number\t%d - day of month\n"
+    ."%H - hour \t%M - minute  \t%S - second\n"
+    ."\$n - number of frames in the file\n"
+    ."\$t - timestamp of the last frame";
 %cfg=(
   vo=>[x11, 'text', "Video output driver (see mplayer -vo help)"],
   ao=>["esd,arts,oss,alsa", 'text', "Audio output driver (see mplayer -ao help)"],
   not_ask=> [0, 'checkbox', "Never show file save dialog again."],
-  out_file=>['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Write video to file(s)",
-     "%@  in the filename will be replaced to source URL\n"
-    ."%Y - year \t%m - month number\t%d - day of month\n"
-    ."%H - hour \t%M - minute  \t%S - second\n"
-    ."\$n - number of frames in the file\n"
-    ."\$t - timestamp of the last frame"
-  ],
-  out_file_once=>['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Save video to file",
-     "%@  in the filename will be replaced to source URL\n"
-    ."%Y - year \t%m - month number\t%d - day of month\n"
-    ."%H - hour \t%M - minute  \t%S - second\n"
-    ."\$n - number of frames in the file\n"
-    ."\$t - timestamp of the last frame"
-  ],
-  frames=>  [10000, 'text', "Frames per file limit"],
+  not_ask_jpegs=> [0, 'checkbox', "Never show save as jpegs dialog again."],
+  out_file_once=>['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Save this video to file", $filehelp],
+  out_file=>     ['%@-%Y-%m-%d_%H-%M-%S.avi', 'file', "Write video to file(s)", $filehelp],
+  out_file_jpegs=>     ['%@-%Y-%m-%d_%H-%M-\$t.jpeg', 'file', "Save this video to jpeg files", $filehelp],
+  out_file_jpegs_auto=>['%@-%Y-%m-%d_%H-%M-\$t.jpeg', 'file', "Write video to jpeg files", $filehelp],
+  frames=> [10000, 'text', "Frames per file limit"],
 );
 $_=$0;  s|[^/]*$||;  @INC=( "$_../..",@INC);
 require "config.pl";
@@ -299,11 +296,13 @@ print "debug=1\n", # list of control variables
       "autostart=\n",
       "play=1\n",
       "save=\n",
+      "saveformat=\n",
       "fps=\n",
       "lowres=\n",
       "rotate=0\n",
       "flip=0\n",
       "mirror=0\n",
+      "framedelay=0\n",
       "src=\n",
       "href=\n" unless($ARGV[0] eq '--no-vars');
       
@@ -330,26 +329,46 @@ while (<STDIN>){
 	$OPTS="";
 	$v{baseURI}=~s|/[^/]*$||;
 	url2mplayer();
-	if($v{save}) { #Recording TODO: ask about overwriting file
+	if($v{save}) { #Recording TODO: ask about file overwriting
 	    $cmd=rtpcmd();
 	    if($cmd) {
-		$cfg{out_file_once}[0]=~s/\.avi/\.ogm/;
-		$cfg{out_file}[0]=~s/\.avi/\.ogm/;
+		$v{saveformat}="ogm" if($v{saveformat} ne "jpeg");
 	    }else{
-		$cfg{out_file_once}[0]=~s/\.ogm/\.avi/;
-		$cfg{out_file}[0]=~s/\.ogm/\.avi/;
+		$v{saveformat}="avi";
 	    }
-	    if(uc $v{save} ne 'AUTO'){
-		if(!file_dialog(out_file_once, frames)) { print "run=0\n"; last};
-		$out_file=$cfg{out_file_once}[0];
-	    }elsif( $cfg{not_ask}[0] ){
-		$out_file=$cfg{out_file}[0];
+	    
+	    if($v{saveformat} eq "jpeg") {
+		$cmd.=" -r -F1" if $cmd;
+	    	if(lc $v{save} ne 'auto'){
+		    if(!file_dialog(out_file_jpegs)) { print "run=0\n"; last};
+		    $out_file=$cfg{out_file_jpegs}[0];
+		}elsif( $cfg{not_ask}[0] ){
+		    $out_file=$cfg{out_file_jpegs_auto}[0];
+		}else{
+		    if(!file_dialog(out_file_jpegs_auto, not_ask_jpegs)) { print "run=0\n"; last};
+		    $out_file=$cfg{out_file_jpegs_auto}[0];
+		}
 	    }else{
-		if(!file_dialog(out_file, not_ask, frames)) { print "run=0\n"; last};
-		$out_file=$cfg{out_file}[0];
+		if($v{saveformat} eq "avi") {
+	    	    $cfg{out_file_once}[0]=~s/\.ogm/\.avi/;
+	    	    $cfg{out_file}[0]=~s/\.ogm/\.avi/;		    
+		}else{
+	    	    $cfg{out_file_once}[0]=~s/\.avi/\.ogm/;
+	    	    $cfg{out_file}[0]=~s/\.avi/\.ogm/;
+		}
+	    	if(lc $v{save} ne 'auto'){
+		    if(!file_dialog(out_file_once, frames)) { print "run=0\n"; last};
+		    $out_file=$cfg{out_file_once}[0];
+		}elsif( $cfg{not_ask}[0] ){
+		    $out_file=$cfg{out_file}[0];
+		}else{
+		    if(!file_dialog(out_file, not_ask, frames)) { print "run=0\n"; last};
+		    $out_file=$cfg{out_file}[0];
+		}
+		$cmd.=" -F '$cfg{frames}[0]'" if $cmd;
 	    }
 	    if($cmd) {
-		$cmd="$cmd -F '$cfg{frames}[0]' -o".suburl($out_file);
+		$cmd.=" -o".suburl($out_file);
 		print "cmd=$cmd\n";
 		runslv $cmd;
 	    } else {
@@ -387,12 +406,14 @@ while (<STDIN>){
 	    $OPTS.=" -xy '$v{width}'"	if( $v{width} && $v{width}!~"%" );
 	    $OPTS.=" -lavdopts lowres='$v{lowres}'" if( $v{lowres} );
 	    $OPTS.=" -fps '$v{fps}'"		if( $v{fps} );
-	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( $href ne "/dev/fd/3" && exists $v{loop} && "\L$v{loop}" ne 'false' );
-	    $loop= 0+$v{loop} if( exists $v{loop} && "\L$v{loop}" ne 'false' );
+	    $OPTS.=" -fixed-vo -loop ".(0+$v{loop}) if( $href ne "/dev/fd/3" && exists $v{loop} && lc $v{loop} ne 'false' );
+	    $loop= 0+$v{loop} if( exists $v{loop} && lc $v{loop} ne 'false' );
 	    $OPTS.= localnet()? " -nocache" : " -cache 1000 -cache-min 50";
 	    if(( $cmd2=rtpcmd() )) {
+	        $cmd2.=" -i -q";
 		$cmd2.=" -k $v{frameskip}" if $v{frameskip};
-	        $cmd2="|exec $cmd2 -i 2>/dev/null ".fileno(PIPE_OUT)."<&- >/dev/fd/".fileno(PIPE_IN);
+		$cmd2.=" -b $v{framedelay}" if $v{framedelay};
+	        $cmd2="|exec $cmd2 2>/dev/null ".fileno(PIPE_OUT)."<&- >/dev/fd/".fileno(PIPE_IN);
 		$cmd="mplayer $OPTS -vo $cfg{vo}[0] -zoom -nojoystick -slave -nomouseinput -cookies /dev/fd/".fileno(PIPE_OUT);
 	        print "cmd=$cmd\n";
 	        print "cmd2=$cmd2\n";
